@@ -76,12 +76,10 @@ lstComparatorBlockMapReference(const void *const blockMapRef1, const void *const
     ASSERT(blockMapRef1 != NULL);
     ASSERT(blockMapRef2 != NULL);
 
-    if (((BlockMapReference *)blockMapRef1)->reference < ((BlockMapReference *)blockMapRef2)->reference)
-        FUNCTION_TEST_RETURN(INT, -1);
-    else if (((BlockMapReference *)blockMapRef1)->reference > ((BlockMapReference *)blockMapRef2)->reference)
-        FUNCTION_TEST_RETURN(INT, 1);
+    const unsigned int reference1 = ((const BlockMapReference *)blockMapRef1)->reference;
+    const unsigned int reference2 = ((const BlockMapReference *)blockMapRef2)->reference;
 
-    FUNCTION_TEST_RETURN(INT, 0);
+    FUNCTION_TEST_RETURN(INT, LST_COMPARATOR_CMP(reference1, reference2));
 }
 
 FN_EXTERN BlockMap *
@@ -487,7 +485,7 @@ blockMapWrite(const BlockMap *const this, IoWrite *const output, const size_t bl
             {
                 ASSERT(
                     superBlock == blockMapGet(this, blockIdx) ||
-                    blockMapGet(this, blockIdx)->block == blockMapGet(this, blockIdx - 1)->block + 1);
+                    (blockIdx > 0 && (blockMapGet(this, blockIdx)->block == blockMapGet(this, blockIdx - 1)->block + 1)));
 
                 ioWrite(output, BUF(blockMapGet(this, blockIdx)->checksum, checksumSize));
             }
